@@ -1,4 +1,4 @@
-import json
+import simplejson as json
 
 from worker import API
 from worker.data.json_encoder import JsonEncoder
@@ -43,7 +43,9 @@ class Alert(LoggingMixin, RollbarMixin):
 
         api = API()
         try:
-            trigger = api.post("/v1/alerts/definitions/trigger/", data=json.dumps(context, cls=JsonEncoder)).data
+            trigger = api.post(
+                "/v1/alerts/definitions/trigger/", data=json.dumps(context, cls=JsonEncoder, ignore_nan=True)
+            ).data
             self.debug(self.asset_id, f"Triggered alert with context -> {context} and received response {trigger}")
             self.last_trigger_timestamp = timestamp
 
