@@ -1,9 +1,10 @@
-import json
+import simplejson as json
 import os
 import sys
 from functools import cached_property
 from typing import List, Union
 
+from worker.data.json_encoder import JsonEncoder
 from worker.mixins.logging import LoggingMixin
 from worker.mixins.rollbar import RollbarMixin
 from worker.state import RedisHandler
@@ -92,7 +93,7 @@ class RedisMixin(LoggingMixin, RollbarMixin):
         :param raise_warnings:
         :return:
         """
-        size_object = sys.getsizeof(json.dumps(state)) / 1024
+        size_object = sys.getsizeof(json.dumps(state, cls=JsonEncoder, ignore_nan=True)) / 1024
 
         if not raise_warnings:
             return size_object
